#include <QtGui/QApplication>
#include "imagesetmaker.h"

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);
    Q_INIT_RESOURCE(imagesetmakerRsrc);
    imageSetMaker ismWindow;

#if defined(Q_WS_S60)
    ismWindow.showMaximized();
#else
    ismWindow.show();
#endif

    return app.exec();
}
